---
title: HIFIS Mission
title_image: default
layout: default
additional_css:
    - services/consulting-iframe.css
    - services/consulting-help-images.css
excerpt:
    Overview of HIFIS Motivation, Structure and Governance.
---

## Motivation for HIFIS
<div class="alert alert-success">
The top position of Helmholtz research is increasingly based on cross-centre and international cooperation and common access to data treasure and -services. At the same time the significance of a sustainable software development for the research process is recognised.
<br>
HIFIS aims to ensure an excellent information environment for outstanding research in all Helmholtz research fields and a seamless and performant IT-infrastructure connecting knowledge from all centres. It will build a secure and easy-to-use collaborative environment with efficiently accessible ICT services from anywhere. HIFIS will also support the development of research software with a high level of quality, visibility and sustainability.
</div>



<div class="image-block">
    <img
        class="help-image left"
        alt="pic"
        src="{{ site.directory.images | relative_url }}/HIFIS_Icon.svg"
    />
    <div>
        <h3 id="participating-centers">Participating centers</h3>
        <p>The following 11 out of 19 Helmholtz centres are members of the HIFIS platform:
        <a href="https://www.awi.de/">AWI</a>, 
        <a href="https://www.desy.de/">DESY</a>, 
        <a href="https://www.dlr.de/">DLR</a>, 
        <a href="https://www.dkfz.de/">DKFZ</a>, 
        <a href="https://www.fz-juelich.de/">FZJ</a>, 
        <a href="https://www.gfz-potsdam.de/">GFZ</a>, 
        <a href="https://www.helmholtz-muenchen.de/">HMGU</a>, 
        <a href="https://www.helmholtz-berlin.de/">HZB</a>, 
        <a href="https://www.hzdr.de/">HZDR</a>, 
        <a href="https://www.kit.edu/">KIT</a>, 
        <a href="https://www.ufz.de/">UFZ</a>.</p>
        <h3 id="internal-structure">Internal structure</h3>
        <p>To achieve its goals, HIFIS works in three Competence Clusters which are distributed throughout different Helmholtz research centers:</p>
        <ul>
          <li><a href="cluster_cloud">Cloud Services</a>: Federated platform for proven first class cloud services; led by <a href="https://www.helmholtz-berlin.de/">HZB</a>.</li>
          <li><a href="cluster_backbone">Backbone Services</a>: High-performance trusted network infrastructure with unified basic services; led by <a href="https://www.desy.de/">DESY</a>.</li>
          <li><a href="cluster_software">Software Services</a>: Platform, training and support for high-quality, sustainable software development, led by <a href="https://www.hzdr.de/">HZDR</a>.</li>
        </ul>
        <p>Within the scope of the declared goals and achievements of the Helmholtz Association for HIFIS, the respective centres steer the competence clusters.
        All competence clusters are connected through the HIFIS ICT Office.</p>
    </div>
</div>



<div class="image-block">
    <img
        class="help-image right"
        alt="pic"
        src="{{ site.directory.images | relative_url }}/HIFIS_Icon.svg"
    />
    <div>
        <h2 id="documentation-and-publications">Documentation and Publications</h2>
        <h3 id="hifis-proposal">HIFIS Proposal</h3>
        <p>The original platform proposal for HIFIS 
        <a href="https://www.helmholtz.de/fileadmin/user_upload/01_forschung/Helmholtz_Inkubator_HIFIS.pdf">can be found here</a>.</p>
        
        <h3 id="documentation">Documentation</h3>
        <p>The technical documentation for HIFIS architectural components 
        <a href="https://hifis.pages.hzdr.de/hifis-technical-documentation/">is located here (restricted access)</a>.</p>
        
        <h3 id="reports-and-conference-contributions">Reports and Conference Contributions</h3>
        <ul>
          <li>Annual report</li>
          <li>Abstracts</li>
          <li>SAB Report</li>
        </ul>
    </div>
</div>




<div class="image-block">
    <img
        class="help-image left"
        alt="pic"
        src="{{ site.directory.images | relative_url }}/HIFIS_Icon.svg"
    />
    <div>
        <h2 id="partners">Partners</h2>
        <p>
            HIFIS is embedded in the context of the <a href="incubator">Helmholtz Information &amp; Data Science Incubator</a> and hence has close collaboration with the four other incubator platforms.
        </p>
        <p>
            For a more extensive list of Helmholtz and international partners, see also our
            <a href="/review-apps/hifis-hifis-net/11-missionpage/partners.html">partners</a>
            page.
        </p>
    </div>
</div>



<div class="image-block">
    <img
        class="help-image right"
        alt="pic"
        src="{{ site.directory.images | relative_url }}/HIFIS_Icon.svg"
    />
    <div>
        
        <h2 id="governance-and-supervision">Governance and Supervision</h2>
        <p>To ensure that HIFIS’s progress and strategy is consistent with the common principles of the Helmholtz Association,
        Reporting, Governance and an external Scientific Advisory Board are central.</p>
        
        <h3 id="ict-office">ICT Office</h3>
        <p>The ICT Office guarantees the technical and organisational coordination as well as the controlling and reporting for HIFIS. 
        It also defines the interface to comparable external committees, as already existent in e.g. FhG or MPG. 
        It coordinates the HIFIS platform and is headed by its speaker Volker Gülzow (DESY) and the coordinators of the competence clusters Ants Finke (HZB) and Uwe Konrad (HZDR), supported by Uwe Jandt (DESY).</p>
        
        <h3 id="ict-federation-board">ICT Federation Board</h3>
        <p>The Assembly of Members of the Helmholtz Association has installed the ICT Federation Board (Steering Board).
        It is responsible for central decisions in HIFIS. 
        According to the specifications of the directors of the Helmholtz Association the Helmholtz ICT Federation Board establishes the annual plan for HIFIS and  reports about the implemented achievements to the Helmholtz Incubator, with the Helmholtz Incubator reporting to the general assembly.
        <a href="members_FedBoard">See here for a full list of members.</a></p>
        
        <h3 id="scientific-advisory-board-sab">Scientific Advisory Board (SAB)</h3>
        <p>Further, the Assembly of Members of the Helmholtz Association has installed the Scientific Advisory Board (SAB). A total of 20 renowned international scientists contribute to HIFIS’s progress by their advice as SAB members.
        <a href="members_SAB">See here for a full list of SAB members.</a></p>        
        
        
        
    </div>
</div>



